@@ -185,7 +185,7 @@ typedef enum {
   inst_none = 0, inst_file, inst_nfs, inst_ftp, inst_smb,
   inst_http, inst_https, inst_tftp, inst_cdrom, inst_floppy, inst_hd,
   inst_dvd, inst_cdwithnet, inst_net, inst_slp, inst_exec,
-  inst_rel, inst_disk, inst_usb, inst_label,
+  inst_rel, inst_disk, inst_usb, inst_label, inst_repo,
   inst_extern ///< must be last
 } instmode_t;
 
@@ -291,6 +291,7 @@ typedef struct {
     unsigned wlan:1;		/**< wlan interface */
     unsigned blockdev:1;	/**< needs block device */
     unsigned nodevneeded:1;	/**< does not need any device */
+    unsigned relative:1;	/**< url is relative (to some other url) */
   } is;
   struct {
     char *device;
@@ -493,6 +494,7 @@ typedef struct {
   enum langid_t language;	/**< currently selected language */
   char *keymap;			/**< current keymap */
   unsigned keymap_set:1;	/**< explicitly set via 'keytable' option */
+  unsigned keymap_applied:1;	/**< config.keymap has been applied via loadkeys command */
   unsigned sourcetype:1;	/**< 0: directory, 1: file */
   char *new_root;		/**< root device to boot */
   char *rootimage;		/**< "boot/<arch>/root" */
